<?php
require_once 'diogenes.common.inc.php';
require_once 'diogenes.toplevel.inc.php';
require_once 'diogenes/diogenes.table-editor.inc.php';

// set up the page
$page = new $globals->toplevel(true);
$page->assign("greeting",__("Global options"));
$page->toolbar(__("Mode"), array( array( __("standard"), "options.php" ), __("expert")));

// set up the editor
$editor = new DiogenesTableEditor($globals->table_global_options,"name",true);
$editor->describe("name", __("option"), false);
$editor->describe("value", __("value"), true);

// run the editor
$editor->run($page,'page_content');
$page->display('');
?>
